===========
Intake-stac
===========

Intake-stac is an open source project and Python package for discovering,
exploring, and loading spatio-temporal datasets.

Intake-stac provides Intake Drivers for SpatioTemporal Asset Catalogs (STAC).
It provides tools for opening STAC ``Catalogs``, ``Collections``,
``ItemCollections``, and ``Items`` as Intake catalogs. Intake and Intake-xarray
provide the tooling for loading assets described in STAC into Xarray objects.

.. toctree::
   :maxdepth: 2
   :caption: Documentation Contents

   installation
   tutorial
   api
   contributing

Feedback
--------

If you encounter any errors or problems with **intake-stac**,
please open an issue at the GitHub `main repository <http://github.com/pangeo-data/intake-stac>`_.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
